==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_addaddress.js <==
_me = frm_addaddress.prototype;
function frm_addaddress(){};

_me.__constructor = function(aOnPopupCloseResponse, aTabsNames, aTabsValues, sPreselectTab,bDistrList)
{
	this._modal(true);

	var me = this;
	this._viewLimit = GWOthers.getItem('LAYOUT_SETTINGS','ab_view_limit');
	this._viewLimit = this._viewLimit>0?this._viewLimit:5;
	
	this._lastOffset = 0;
	this._datagridData;

	this._distrList = bDistrList;

	this._title('SELECT_RECIPIENTS::SELECT_RECIPIENTS');
	this._size(700);

	this._draw('frm_addaddress', 'main');

	// LEFT
	this._create('grid','obj_datagrid','left');

    this.grid._skipsort = true;
	this.grid.__sortColumn = 'LABEL';
    this.grid.__sortType = 0;
	this.grid._addColumns({'LABEL':{"title": 'DATAGRID_ITEMS_VIEW::ITMCLASSIFYAS',"width":'120','arg':{'sort':'asc'}},'EMAIL':{"title": 'DATAGRID_ITEMS_VIEW::CONTACT_EMAIL',"width":'150'}});

    
	this.grid._oncontext = function(e,elm,etr,arg,sLineId,sColumn) {
		if (arg) {
			var menu = gui._create('context', 'obj_context');
			var id = [arg['aid'], arg['fid'], arg['iid']];

			menu._place(e.clientX,e.clientY);
			menu._fill([{"title": 'POPUP_ITEMS::EDIT', 'arg': [Item.open, [id]]}]);

			menu._onclick = function(e, elm, id, arg) {
				if (!arg) return;
				executeCallbackFunction(arg);
			};
		}
	};

	this.grid._ondblclick = function(e){
		me.__copyContactFromDatagridToSelect(this._value(),me.tabs._value());
	};

	this.__orderStr = 'ITMCLASSIFYAS asc, ITMTITLE asc, ITMFIRSTNAME asc, ITMMIDDLENAME asc, ITMSURNAME asc, ITMSUFFIX asc';

	this.grid._onsort = function(e,elm,id,arg,sType){
		if (sType == 'asc')
			me.__orderStr = me.__orderStr.replace('desc','asc');
		else
			me.__orderStr = me.__orderStr.replace('asc','desc');

		me.__fillDatagrid(sPrimaryAccount, me._activeFolder);
	};

	this.__aSelectRows = {};

	for (var i in aTabsNames)
		this.__aSelectRows[i] = [];

	this._activeFolder = Mapping.getDefaultFolderForGWType('C');

	this.lister._value(0,true);
	this.lister._list(this._viewLimit);
/*
	this.lister.__update = function(){
		me.lister._range(dataSet.get('folders',[sPrimaryAccount,me._activeFolder,'TOTAL']),true);
	};
*/
	this.lister._onchange = function(value){
		me._lastOffset = value;
		me.__fillDatagrid(sPrimaryAccount,me._activeFolder);
	};
	this.lister.__update();


	// CENTER
	this.r.__eIN.value ='>';
	this.r._onclick = function(){
		me.__copyContactFromDatagridToSelect(me.grid._value(), me.tabs._value());
	};

	this.rr.__eIN.value = '>>';
	this.rr._onclick = function(){
		me.__copyAllContactsFromDatagridToSelect(me.tabs._value());
	};

	this.l.__eIN.value = '<';
	this.l._onclick = function(){
		var sTab = me.tabs._value();
		me.__removeContactFromSelect(me.tabs[sTab].select._value(),sTab);
	};

	this.ll.__eIN.value = '<<';
	this.ll._onclick = function(){
		me.__removeAllContactsFromSelect(me.tabs._value());
	};

	this.remove.__eIN.value = '<<<';
	this.remove._onclick = function(){
		for (var i in aTabsNames)
			me.__removeAllContactsFromSelect(i);
	};

	// RIGHT TABS
	this._create('tabs','obj_tabs','right');

	for (var i in aTabsNames){
		this.tabs._create(i,'obj_tab');
		this.tabs[i]._value(aTabsNames[i]);
		this.tabs[i]._create('select','obj_listbox');
		this.tabs[i].select._multiple(true);
		if (Is.Defined(aTabsValues) && Is.Defined(aTabsValues[i]))
			this.__addItemsIntoSelect(MailAddress.splitEmails(aTabsValues[i]), i);

		this.tabs[i].select._ondblclick = function(e,id,value){
			me.__removeContactFromSelect(value,this._parent._name);
		};
	}

	if (Is.Defined(sPreselectTab))
		this.tabs._value(sPreselectTab);

	// ADD
	this._create('inpadd','obj_input','addinput');
	this.inpadd._onerror = function(bErr){
		me.btnadd._disabled(bErr);
	};

	this._create('btnadd','obj_button','addbutton');
	this.btnadd._value('SELECT_RECIPIENTS::ADD');
	this.btnadd._onclick = function(){
		var sTab = me.tabs._value();
		aValues = MailAddress.splitEmails(me.inpadd._value());
		for (var i in aValues)
			if (inArray(me.__aSelectRows[sTab],aValues[i]) == -1)
				me.__aSelectRows[sTab].push(aValues[i]);

		me.tabs[sTab].select._fill(me.__aSelectRows[sTab]);

		me.inpadd._value('');
	};

	// FOOTER
	this._create('ok','obj_button','footer');
	this.ok._value('FORM_BUTTONS::OK');
	me.__ok = false;
	this.ok._onclick = function(){
		me.__ok = true;
		me._destruct();
	};

	this._create('cancel','obj_button','footer');
	this.cancel._value('FORM_BUTTONS::CANCEL');
	this.cancel._onclick = function(){
		me._destruct();
	};

	this._onclose = function(){
		if (typeof aOnPopupCloseResponse != 'undefined'){
			if (me.__ok && me.inpadd._value() != '')
				me.btnadd._onclick();

			var aReturnVars = {};
			for (var i in aTabsNames)
				aReturnVars[i] = compact(me.__aSelectRows[i]);
				
			executeCallbackFunction(aOnPopupCloseResponse, me.__ok, aReturnVars);
		}
		return true;
	};

	this.folders._onclick = function(){
		sFolderType = dataSet.get("folders",[sPrimaryAccount,me._activeFolder,'TYPE']);
		gui._create('frm_select_folder','frm_select_folder','','','POPUP_FOLDERS::SELECT_FOLDER',sPrimaryAccount,me._activeFolder,[me,'__changeFolder'],true,true,sFolderType,'',true);
	};

	this.__fillDatagrid(sPrimaryAccount, this._activeFolder);

	// SEARCH
/*
	this.search._restrict(".+");
	this.search._onerror = function(b){
		me.btn_search._disabled(b?true:false);
		//document.title = (b?"A":"B");
	}
*/
	this.search._onsearch = function(v){
		if (v === me._SQLsearch) return;

		me._SQLsearch = v;

		// QUOTE HERE
		v = v.quoteSQL();
		me._SQLfilter = 'LCTEMAIL1 LIKE \'%'+v+'%\' OR LCTEMAIL2 LIKE \'%'+v+'%\' OR LCTEMAIL3 LIKE \'%'+v+'%\' OR '+
						'ITMCLASSIFYAS LIKE \'%'+v+'%\' OR ITMFIRSTNAME LIKE \'%'+v+'%\' OR ITMMIDDLENAME LIKE \'%'+v+'%\' OR ITMSURNAME LIKE \'%'+v+'%\'';

		me.__fillDatagrid(sPrimaryAccount, me._activeFolder);
	};

	this.btn_search._onclick = function(){
		me.search._onsearch(me.search._value());
	};
};

_me.__fillDatagrid = function(sAID, sFID)
{
	var aValues;
	var aFilter = {'offset':this._lastOffset,'limit':this._viewLimit,'order_by':this.__orderStr};

    aFilter['sql'] = "(LCTEMAIL1 NOT LIKE '' OR LCTEMAIL2 NOT LIKE '' OR LCTEMAIL3 NOT LIKE '')";

	if (this._SQLfilter)
		aFilter['sql'] += ' AND ('+ this._SQLfilter +')';

	aValues = WMItems.list({'aid':sAID,'fid':sFID,'values':['ITMTITLE','ITMCLASS','ITMCLASSIFYAS','ITMFIRSTNAME','ITMMIDDLENAME','ITMSURNAME','ITMSUFFIX','LCTEMAIL1','LCTEMAIL2','LCTEMAIL3','LCTTYPE'],'filter':aFilter,'order_by':this.__orderStr})[sAID][sFID];
	
	//TOTAL set items count
	if (aValues['/']){
		if (aValues['/']>=0)
			this.lister._range(aValues['/'],true);
		delete aValues['/'];
	}
	//SUBTOTAL set items count
	if (aValues['#'])
		delete aValues['#'];

	// Clear old rows
	var aDatagridRows = [];

	if (this._SQLsearch)
		var rxp  = new RegExp('('+this._SQLsearch+')', "gi");
	
	for (var i in aValues){

		if (aValues[i]['ITMCLASS'] == 'L'){
			if (this._distrList) {
				var sPrefix = '';
				var sName = aValues[i]['ITMTITLE'];

				if (sAID != sPrimaryAccount || sName.indexOf('::') >= 0)
					sPrefix = sAID + '::' + sFID + '::';
				else if (sFID != Mapping.getDefaultFolderForGWType('C'))
					sPrefix = sFID + '::';

				aDatagridRows.push({"id":i,"data":{'LABEL':'['+sPrefix+sName+']','EMAIL':''},"arg":{'aid':aValues[i]['aid'],'fid':aValues[i]['fid'],'iid': i}});
			}
		}
		else{
			var sEmail,sName,sFullName = '';
			
			if (!aValues[i]['ITMCLASSIFYAS']){
				var aFullNameParts = ['ITMTITLE','ITMFIRSTNAME','ITMMIDDLENAME','ITMSURNAME','ITMSUFFIX'];

				for (var n in aFullNameParts)
					if (aValues[i][aFullNameParts[n]])
						sFullName += aValues[i][aFullNameParts[n]] + ' ';

				sFullName.trim();
			}
			else
				sFullName = aValues[i]['ITMCLASSIFYAS'];

			//highlight Name
			if (this._SQLsearch)
				sName = sFullName.replace(rxp,"<b>$1</b>");
			else
			    sName = sFullName;
            
			if (Is.Defined(aValues[i]['LCTEMAIL1']) && aValues[i]['LCTEMAIL1'] != 'undefined'){
                //highlight Email1
				if (this._SQLsearch)
					sEmail = aValues[i]['LCTEMAIL1'].replace(rxp,"<b>$1</b>");
				else
				    sEmail = aValues[i]['LCTEMAIL1'];
				
				aDatagridRows.push({"id":i+'#1',"data":{'LABEL':[sName,sFullName],'EMAIL':[sEmail,aValues[i]['LCTEMAIL1']]},"arg":{'aid':aValues[i]['aid'],'fid':aValues[i]['fid'],'iid': i}});
			}
			
			if (Is.Defined(aValues[i]['LCTEMAIL2']) && aValues[i]['LCTEMAIL2'] != 'undefined'){
                //highlight Email2
				if (this._SQLsearch)
					sEmail = aValues[i]['LCTEMAIL2'].replace(rxp,"<b>$1</b>");
				else
				    sEmail = aValues[i]['LCTEMAIL2'];

				aDatagridRows.push({"id":i+'#2',"data":{'LABEL':[sName,sFullName],'EMAIL':[sEmail,aValues[i]['LCTEMAIL2']]},"arg":{'aid':aValues[i]['aid'],'fid':aValues[i]['fid'],'iid': i}});
			}
			if (Is.Defined(aValues[i]['LCTEMAIL3']) && aValues[i]['LCTEMAIL3'] != 'undefined'){
                //highlight Email3
				if (this._SQLsearch)
					sEmail = aValues[i]['LCTEMAIL3'].replace(rxp,"<b>$1</b>");
				else
				    sEmail = aValues[i]['LCTEMAIL3'];

				aDatagridRows.push({"id":i+'#3',"data":{'LABEL':[sName,sFullName],'EMAIL':[sEmail,aValues[i]['LCTEMAIL3']]},"arg":{'aid':aValues[i]['aid'],'fid':aValues[i]['fid'],'iid': i}});
			}
		}
	}
	// Render new datas
	this.grid._fill(aDatagridRows);
};

_me.__copyContactFromDatagridToSelect = function(aIDs,sTab) {
	var nPosition;
	var sData;

	//inspect2({aIDs:aIDs,idt:this.grid.__idTable});

	var id,sName;
	for (var i in aIDs){
		if(typeof (id=this.grid.__idTable[aIDs[i]]) == 'undefined') continue;

		//distribution list
		if (!this.grid._aData[id].data.EMAIL && typeof this.grid._aData[id].data.LABEL == 'string')
			sData = this.grid._aData[id].data.LABEL;
		//contact
		else
			sData = (this.grid._aData[id].data.LABEL[1]?'"'+ this.grid._aData[id].data.LABEL[1] +'" ':'')+(this.grid._aData[id].data.EMAIL[1]?'<'+ this.grid._aData[id].data.EMAIL[1] +'>':'');

		sData.trim();
		
		if (inArray(this.__aSelectRows[sTab],sData) == -1)
			this.__aSelectRows[sTab].push(sData);
	}

	// Refresh select
	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__copyAllContactsFromDatagridToSelect = function(sTab) {
    var sData;
	for (var id in this.grid._aData){
		sData = (this.grid._aData[id].data.LABEL[1]?'"'+ this.grid._aData[id].data.LABEL[1] +'" ':'')+(this.grid._aData[id].data.EMAIL[1]?'<'+ this.grid._aData[id].data.EMAIL[1] +'>':'');

		if (inArray(this.__aSelectRows[sTab],sData) == -1)
			this.__aSelectRows[sTab].push(sData);
	}

	// Refresh select
	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__removeContactFromSelect = function(aIDs,sTab) {
	for (var i in aIDs)
		delete this.__aSelectRows[sTab][aIDs[i]];
		
	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__removeAllContactsFromSelect = function(sTab) {
	this.__aSelectRows[sTab] = [];
	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__addItemsIntoSelect = function(aItems, sTab) {
	for (var i in aItems)
		this.__aSelectRows[sTab].push(aItems[i]);

	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__changeFolder = function(sAccount,sFolder) {
	this._activeFolder = sFolder;
	this.lister._value(0);
	this.lister.__update();
	this._datagridData = '';
	this.__fillDatagrid(sPrimaryAccount,sFolder);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_addaddress.js <==
_me = frm_addaddress.prototype;
function frm_addaddress(){};

_me.__constructor = function(aOnPopupCloseResponse, aTabsNames, aTabsValues, sPreselectTab,bDistrList)
{
	this._modal(true);

	var me = this;
	this._viewLimit = GWOthers.getItem('LAYOUT_SETTINGS','ab_view_limit');
	this._viewLimit = this._viewLimit>0?this._viewLimit:5;
	
	this._lastOffset = 0;
	this._datagridData;

	this._distrList = bDistrList;

	this._title('SELECT_RECIPIENTS::SELECT_RECIPIENTS');
	this._size(700,'',true);

	this._draw('frm_addaddress', 'main');

	// LEFT
	this._create('grid','obj_datagrid','left');

    this.grid._skipsort = true;
	this.grid.__sortColumn = 'LABEL';
    this.grid.__sortType = 0;
	this.grid._addColumns({'LABEL':{"title": 'DATAGRID_ITEMS_VIEW::ITMCLASSIFYAS',"width":'120','arg':{'sort':'asc'}},'EMAIL':{"title": 'DATAGRID_ITEMS_VIEW::CONTACT_EMAIL',"width":'150'}});

    
	this.grid._oncontext = function(e,elm,etr,arg,sLineId,sColumn) {
		if (arg) {
			var menu = gui._create('context', 'obj_context');
			var id = [arg['aid'], arg['fid'], arg['iid']];

			menu._place(e.clientX,e.clientY);
			menu._fill([{"title": 'POPUP_ITEMS::EDIT', 'arg': [Item.open, [id]]}]);

			menu._onclick = function(e, elm, id, arg) {
				if (!arg) return;
				executeCallbackFunction(arg);
			};
		}
	};

	this.grid._ondblclick = function(e){
		me.__copyContactFromDatagridToSelect(this._value(),me.tabs._value());
	};

	this.__orderStr = 'ITMCLASSIFYAS asc, ITMTITLE asc, ITMFIRSTNAME asc, ITMMIDDLENAME asc, ITMSURNAME asc, ITMSUFFIX asc';

	this.grid._onsort = function(e,elm,id,arg,sType){
		if (sType == 'asc')
			me.__orderStr = me.__orderStr.replace('desc','asc');
		else
			me.__orderStr = me.__orderStr.replace('asc','desc');

		me.__fillDatagrid(sPrimaryAccount, me._activeFolder);
	};

	this.__aSelectRows = {};

	for (var i in aTabsNames)
		this.__aSelectRows[i] = [];

	this._activeFolder = Mapping.getDefaultFolderForGWType('C');

	this.lister._value(0,true);
	this.lister._list(this._viewLimit);
/*
	this.lister.__update = function(){
		me.lister._range(dataSet.get('folders',[sPrimaryAccount,me._activeFolder,'TOTAL']),true);
	};
*/
	this.lister._onchange = function(value){
		me._lastOffset = value;
		me.__fillDatagrid(sPrimaryAccount,me._activeFolder);
	};
	this.lister.__update();


	// CENTER
	this.r.__eIN.value ='>';
	this.r._onclick = function(){
		me.__copyContactFromDatagridToSelect(me.grid._value(), me.tabs._value());
	};

	this.rr.__eIN.value = '>>';
	this.rr._onclick = function(){
		me.__copyAllContactsFromDatagridToSelect(me.tabs._value());
	};

	this.l.__eIN.value = '<';
	this.l._onclick = function(){
		var sTab = me.tabs._value();
		me.__removeContactFromSelect(me.tabs[sTab].select._value(),sTab);
	};

	this.ll.__eIN.value = '<<';
	this.ll._onclick = function(){
		me.__removeAllContactsFromSelect(me.tabs._value());
	};

	this.remove.__eIN.value = '<<<';
	this.remove._onclick = function(){
		for (var i in aTabsNames)
			me.__removeAllContactsFromSelect(i);
	};

	// RIGHT TABS
	this._create('tabs','obj_tabs','right');

	for (var i in aTabsNames){
		this.tabs._create(i,'obj_tab');
		this.tabs[i]._value(aTabsNames[i]);
		this.tabs[i]._create('select','obj_listbox');
		this.tabs[i].select._multiple(true);
		if (Is.Defined(aTabsValues) && Is.Defined(aTabsValues[i]))
			this.__addItemsIntoSelect(MailAddress.splitEmails(aTabsValues[i]), i);

		this.tabs[i].select._ondblclick = function(e,id,value){
			me.__removeContactFromSelect(value,this._parent._name);
		};
	}

	if (Is.Defined(sPreselectTab))
		this.tabs._value(sPreselectTab);

	// ADD
	this._create('inpadd','obj_input','addinput');
	this.inpadd._onerror = function(bErr){
		me.btnadd._disabled(bErr);
	};

	this._create('btnadd','obj_button','addbutton');
	this.btnadd._value('SELECT_RECIPIENTS::ADD');
	this.btnadd._onclick = function(){
		var sTab = me.tabs._value();
		aValues = MailAddress.splitEmails(me.inpadd._value());
		for (var i in aValues)
			if (inArray(me.__aSelectRows[sTab],aValues[i]) == -1)
				me.__aSelectRows[sTab].push(aValues[i]);

		me.tabs[sTab].select._fill(me.__aSelectRows[sTab]);

		me.inpadd._value('');
	};

	// FOOTER
	this._create('ok','obj_button','footer');
	this.ok._value('FORM_BUTTONS::OK');
	me.__ok = false;
	this.ok._onclick = function(){
        me.__ok = true;
		me._destruct();
	};

	this._create('cancel','obj_button','footer');
	this.cancel._value('FORM_BUTTONS::CANCEL');
	this.cancel._onclick = function(){
		me._destruct();
	};

	this._onclose = function(){

		if (typeof aOnPopupCloseResponse != 'undefined'){

			if (me.__ok && me.inpadd._value() != '')
				me.btnadd._onclick();

			var aReturnVars = {};
			for (var i in aTabsNames)
				aReturnVars[i] = compact(me.__aSelectRows[i]);

            pushParameterToCallback(aOnPopupCloseResponse, me);
			executeCallbackFunction(aOnPopupCloseResponse, me.__ok, aReturnVars);
		}
		return true;
	};

	this.folders._onclick = function(){
		sFolderType = dataSet.get("folders",[sPrimaryAccount,me._activeFolder,'TYPE']);
		gui._create('frm_select_folder','frm_select_folder','','','POPUP_FOLDERS::SELECT_FOLDER',sPrimaryAccount,me._activeFolder,[me,'__changeFolder'],true,true,sFolderType,'',true);
	};

	this.__fillDatagrid(sPrimaryAccount, this._activeFolder);

	// SEARCH
/*
	this.search._restrict(".+");
	this.search._onerror = function(b){
		me.btn_search._disabled(b?true:false);
		//document.title = (b?"A":"B");
	}
*/
	this.search._onsearch = function(v){
		if (v === me._SQLsearch) return;

		me._SQLsearch = v;

		// QUOTE HERE
		v = v.quoteSQL();
		me._SQLfilter = 'LCTEMAIL1 LIKE \'%'+v+'%\' OR LCTEMAIL2 LIKE \'%'+v+'%\' OR LCTEMAIL3 LIKE \'%'+v+'%\' OR '+
						'ITMCLASSIFYAS LIKE \'%'+v+'%\' OR ITMFIRSTNAME LIKE \'%'+v+'%\' OR ITMMIDDLENAME LIKE \'%'+v+'%\' OR ITMSURNAME LIKE \'%'+v+'%\'';

		me.__fillDatagrid(sPrimaryAccount, me._activeFolder);
	};

	this.btn_search._onclick = function(){
		me.search._onsearch(me.search._value());
	};
};

_me.__fillDatagrid = function(sAID, sFID)
{
	var dgw = GWOthers.getItem('RESTRICTIONS', 'disable_gw_types');
	if (sPrimaryAccountGW<1 || (dgw && dgw.indexOf('c')>-1)) return;

	var aValues;
	var aFilter = {'offset':this._lastOffset,'limit':this._viewLimit,'order_by':this.__orderStr};

	aFilter['sql'] = "((NOT (LCTEMAIL1 = '')) OR (NOT (LCTEMAIL2 = '')) OR (NOT (LCTEMAIL3 = '')))";

	if (this._SQLfilter)
		aFilter['sql'] += ' AND ('+ this._SQLfilter +')';

	aValues = WMItems.list({'aid':sAID,'fid':sFID,'values':['ITMTITLE','ITMCLASS','ITMCLASSIFYAS','ITMFIRSTNAME','ITMMIDDLENAME','ITMSURNAME','ITMSUFFIX','LCTEMAIL1','LCTEMAIL2','LCTEMAIL3','LCTTYPE'],'filter':aFilter,'order_by':this.__orderStr})[sAID][sFID];
	
	//TOTAL set items count
	if (aValues['/'])
		if (aValues['/']>=0)
			this.lister._range(aValues['/'],true);

	delete aValues['/'];

	//SUBTOTAL set items count
	delete aValues['#'];

	//OFFSET
	delete aValues['$'];

	// Clear old rows
	var aDatagridRows = [];

	if (this._SQLsearch)
		var rxp  = new RegExp('('+this._SQLsearch+')', "gi");

	for (var i in aValues){

		if (aValues[i]['ITMCLASS'] == 'L'){
			if (this._distrList) {
				var sPrefix = '';
				var sName = aValues[i]['ITMTITLE'];

				if (sAID != sPrimaryAccount || sName.indexOf('::') >= 0)
					sPrefix = sAID + '::' + sFID + '::';
				else if (sFID != Mapping.getDefaultFolderForGWType('C'))
					sPrefix = sFID + '::';

				aDatagridRows.push({"id":i,"data":{'LABEL':'['+sPrefix+sName+']','EMAIL':''},"arg":{'aid':aValues[i]['aid'],'fid':aValues[i]['fid'],'iid': i}});
			}
		}
		else{
			var sEmail,sName,sFullName = '';

			if (!aValues[i]['ITMCLASSIFYAS']){
				var aFullNameParts = ['ITMTITLE','ITMFIRSTNAME','ITMMIDDLENAME','ITMSURNAME','ITMSUFFIX'];

				for (var n in aFullNameParts)
					if (aValues[i][aFullNameParts[n]])
						sFullName += aValues[i][aFullNameParts[n]] + ' ';

				sFullName.trim();
			}
			else
				sFullName = aValues[i]['ITMCLASSIFYAS'];

			//highlight Name
			if (this._SQLsearch)
				sName = sFullName.replace(rxp,"<b>$1</b>");
			else
			    sName = sFullName;
            
			if (Is.Defined(aValues[i]['LCTEMAIL1']) && aValues[i]['LCTEMAIL1'] != 'undefined'){
                //highlight Email1
				if (this._SQLsearch)
					sEmail = aValues[i]['LCTEMAIL1'].replace(rxp,"<b>$1</b>");
				else
				    sEmail = aValues[i]['LCTEMAIL1'];
				
				aDatagridRows.push({"id":i+'#1',"data":{'LABEL':[sName,sFullName],'EMAIL':[sEmail,aValues[i]['LCTEMAIL1']]},"arg":{'aid':aValues[i]['aid'],'fid':aValues[i]['fid'],'iid': i}});
			}
			
			if (Is.Defined(aValues[i]['LCTEMAIL2']) && aValues[i]['LCTEMAIL2'] != 'undefined'){
                //highlight Email2
				if (this._SQLsearch)
					sEmail = aValues[i]['LCTEMAIL2'].replace(rxp,"<b>$1</b>");
				else
				    sEmail = aValues[i]['LCTEMAIL2'];

				aDatagridRows.push({"id":i+'#2',"data":{'LABEL':[sName,sFullName],'EMAIL':[sEmail,aValues[i]['LCTEMAIL2']]},"arg":{'aid':aValues[i]['aid'],'fid':aValues[i]['fid'],'iid': i}});
			}
			if (Is.Defined(aValues[i]['LCTEMAIL3']) && aValues[i]['LCTEMAIL3'] != 'undefined'){
                //highlight Email3
				if (this._SQLsearch)
					sEmail = aValues[i]['LCTEMAIL3'].replace(rxp,"<b>$1</b>");
				else
				    sEmail = aValues[i]['LCTEMAIL3'];

				aDatagridRows.push({"id":i+'#3',"data":{'LABEL':[sName,sFullName],'EMAIL':[sEmail,aValues[i]['LCTEMAIL3']]},"arg":{'aid':aValues[i]['aid'],'fid':aValues[i]['fid'],'iid': i}});
			}
		}
	}
	// Render new datas
	this.grid._fill(aDatagridRows);
};

_me.__copyContactFromDatagridToSelect = function(aIDs,sTab) {
	var nPosition;
	var sData;

	var id,sName;
	for (var i in aIDs){
		if(typeof (id=this.grid.__idTable[aIDs[i]]) == 'undefined') continue;

		//distribution list
		if (!this.grid._aData[id].data.EMAIL && typeof this.grid._aData[id].data.LABEL == 'string')
			sData = this.grid._aData[id].data.LABEL;
		//contact
		else
			sData = (this.grid._aData[id].data.LABEL[1]?'"'+ this.grid._aData[id].data.LABEL[1] +'" ':'')+(this.grid._aData[id].data.EMAIL[1]?'<'+ this.grid._aData[id].data.EMAIL[1] +'>':'');

		sData.trim();
		
		if (inArray(this.__aSelectRows[sTab],sData) == -1)
			this.__aSelectRows[sTab].push(sData);
	}

	// Refresh select
	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__copyAllContactsFromDatagridToSelect = function(sTab) {
    var sData;
	for (var id in this.grid._aData){
		sData = (this.grid._aData[id].data.LABEL[1]?'"'+ this.grid._aData[id].data.LABEL[1] +'" ':'')+(this.grid._aData[id].data.EMAIL[1]?'<'+ this.grid._aData[id].data.EMAIL[1] +'>':'');

		if (inArray(this.__aSelectRows[sTab],sData) == -1)
			this.__aSelectRows[sTab].push(sData);
	}

	// Refresh select
	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__removeContactFromSelect = function(aIDs,sTab) {
	for (var i in aIDs)
		delete this.__aSelectRows[sTab][aIDs[i]];
		
	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__removeAllContactsFromSelect = function(sTab) {
	this.__aSelectRows[sTab] = [];
	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__addItemsIntoSelect = function(aItems, sTab) {
	for (var i in aItems)
		this.__aSelectRows[sTab].push(aItems[i]);

	this.tabs[sTab].select._fill(this.__aSelectRows[sTab]);
};

_me.__changeFolder = function(sAccount,sFolder) {
	this._activeFolder = sFolder;
	this.lister._value(0);
	this.lister.__update();
	this._datagridData = '';
	this.__fillDatagrid(sPrimaryAccount,sFolder);
};
